@@ -15,7 +15,7 @@ def crontab_set(content):
 
 def crontab_show():
     """ Shows current crontab """
-    print _get_current()
+    puts(_get_current())
 
 def crontab_add(content, marker=None):
     """ Adds line to crontab. Line can be appended with special marker
